util

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 11, 2024 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EventAttendees

func EventAttendees(cal *ical.Calendar) map[string]string

EventAttendees returns a map of email addresses of attendees to their participation status

func EventDTEnd

func EventDTEnd(cal *ical.Calendar) (time.Time, error)

EventDTEnd returns the latest end time from all the events in the cal object

func EventDTStart

func EventDTStart(cal *ical.Calendar) (time.Time, error)

EventDTStart returns the earliest start time from all the events in the cal object

func EventDescription

func EventDescription(cal *ical.Calendar) string

EventDescription returns the concatenation of descriptions of all the events in the cal object

func EventOrganizers

func EventOrganizers(cal *ical.Calendar) map[string]string

EventOrganizers returns a map of email addresses of organizers to their participation status

func EventSummary

func EventSummary(cal *ical.Calendar) string

EventSummary returns the concatenation of summaries of all the events in the cal object

func EventUid

func EventUid(cal *ical.Calendar) (string, error)

EventUid returns the UID of calendar event. If the cal object doesn't have exactly one event and one UID prop an error is returned.

Types

This section is empty.

Jump to