Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Backend ¶
type Backend interface {
Get(ctx context.Context, data Data) (Data, error)
Put(ctx context.Context, data Data) error
Close() error
}
func NewBoltBackend ¶
func NewDummyBackend ¶
func NewDummyBackend() Backend
NewDummyBackend returns a Backend. This backend does not store any data and always returns nil for error and echoes back the data
func NewFileBackend ¶
type BoltBackend ¶
type BoltBackend struct {
// contains filtered or unexported fields
}
func (*BoltBackend) Close ¶
func (bb *BoltBackend) Close() error
type DummyBackend ¶
type DummyBackend struct{}
func (*DummyBackend) Close ¶
func (b *DummyBackend) Close() error
type FileBackend ¶
type FileBackend struct {
// contains filtered or unexported fields
}
func (*FileBackend) Close ¶
func (fb *FileBackend) Close() error
Click to show internal directories.
Click to hide internal directories.