Documentation
¶
Index ¶
- func EventAttendees(cal *ical.Calendar) map[string]string
- func EventDTEnd(cal *ical.Calendar) (time.Time, error)
- func EventDTStart(cal *ical.Calendar) (time.Time, error)
- func EventDescription(cal *ical.Calendar) string
- func EventOrganizers(cal *ical.Calendar) map[string]string
- func EventSummary(cal *ical.Calendar) string
- func EventUid(cal *ical.Calendar) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EventAttendees ¶
EventAttendees returns a map of email addresses of attendees to their participation status
func EventDTEnd ¶
EventDTEnd returns the latest end time from all the events in the cal object
func EventDTStart ¶
EventDTStart returns the earliest start time from all the events in the cal object
func EventDescription ¶
EventDescription returns the concatenation of descriptions of all the events in the cal object
func EventOrganizers ¶
EventOrganizers returns a map of email addresses of organizers to their participation status
func EventSummary ¶
EventSummary returns the concatenation of summaries of all the events in the cal object
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.